@@ -4,6 +4,7 @@
 #pragma once
 
 #include "account/identity.h"
+#include "account/notificationfilteringpolicy.h"
 #include "account/preferences.h"
 #include "accountconfig.h"
 #include "admin/adminaccountinfo.h"
@@ -16,7 +17,6 @@
 class Notification;
 class QNetworkReply;
 class QHttpMultiPart;
-class Preferences;
 
 /**
  * @brief Represents an account, which could possibly be real or a mock for testing.
@@ -44,6 +44,9 @@ class AbstractAccount : public QObject
     Q_PROPERTY(bool registrationsOpen READ registrationsOpen NOTIFY fetchedInstanceMetadata)
     Q_PROPERTY(QString registrationMessage READ registrationMessage NOTIFY fetchedInstanceMetadata)
     Q_PROPERTY(int unreadNotificationsCount READ unreadNotificationsCount NOTIFY unreadNotificationsCountChanged)
+    Q_PROPERTY(NotificationFilteringPolicy *notificationFilteringPolicy READ notificationFilteringPolicy CONSTANT)
+    Q_PROPERTY(int maxMediaAttachments READ maxMediaAttachments CONSTANT)
+    Q_PROPERTY(QStringList attachmentFilterStrings READ attachmentFilterStrings CONSTANT)
 
 public:
     /**
@@ -110,6 +113,11 @@ public:
      */
     [[nodiscard]] Preferences *preferences() const;
 
+    /**
+     * @return The server-side notification filtering policy.
+     */
+    [[nodiscard]] NotificationFilteringPolicy *notificationFilteringPolicy() const;
+
     /**
      * @return The username of the account.
      * @see setUsername()
@@ -260,6 +268,20 @@ public:
      */
     void unpin(Post *p);
 
+    /**
+     * @brief Mute a post's conversation.
+     * @param p The post object to mutate.
+     * @see unmute()
+     */
+    void mute(Post *p);
+
+    /**
+     * @brief Unmute a post's conversation.
+     * @param p The post object to mutate.
+     * @see mute()
+     */
+    void unmute(Post *p);
+
     /**
      * @brief Returns a streaming url for @p stream.
      * @param stream The requested stream (e.g. user).
@@ -420,6 +442,10 @@ public:
 
     [[nodiscard]] int unreadNotificationsCount() const;
 
+    [[nodiscard]] int maxMediaAttachments() const;
+
+    [[nodiscard]] QStringList attachmentFilterStrings() const;
+
     /**
      * @brief Update the push notification rules.
      */
@@ -512,6 +538,21 @@ public:
      */
     [[nodiscard]] QString accessTokenKey() const;
 
+    /**
+     * @brief Add a list to this account's favorites.
+     */
+    Q_INVOKABLE void addFavoriteList(const QString &id);
+
+    /**
+     * @brief Remove a list from this account's favorites.
+     */
+    Q_INVOKABLE void removeFavoriteList(const QString &id);
+
+    /**
+     * @return If this list is favorited.
+     */
+    Q_INVOKABLE bool isFavoriteList(const QString &id);
+
     /**
      * @brief Type of account action.
      */
@@ -631,6 +672,12 @@ Q_SIGNALS:
      */
     void fetchedOEmbed(const QString &html);
 
+    /**
+     * @brief Emitted when the list of favorite lists changed.
+     * @see addFavoriteList() removeFavoriteList()
+     */
+    void favoriteListsChanged();
+
 protected:
     explicit AbstractAccount(const QString &instanceUri, QObject *parent = nullptr);
 
@@ -683,6 +730,7 @@ protected:
     AdminAccountInfo *m_federationIdentity{};
     std::shared_ptr<ReportInfo> m_reportInfo;
     Preferences *m_preferences = nullptr;
+    NotificationFilteringPolicy *m_notificationFilteringPolicy = nullptr;
     QList<CustomEmoji> m_customEmojis;
     QString m_additionalScopes;
     AccountConfig *m_config = nullptr;
@@ -691,6 +739,8 @@ protected:
     int m_followRequestCount = 0;
     int m_unreadNotificationsCount = 0;
     QString m_redirectUri;
+    int m_maxMediaAttachments;
+    QStringList m_attachmentFilterStrings;
 
     // updates and notifications
     void handleNotification(const QJsonDocument &doc);
