@@ -18,7 +18,12 @@ class NotificationModel : public AbstractTimelineModel
     Q_PROPERTY(QStringList excludeTypes READ excludeTypes WRITE setExcludesTypes NOTIFY excludeTypesChanged)
 
 public:
-    enum NotificationRoles { ReportRole = ExtraRole, RelationshipSeveranceEventRole, ModerationWarningRole };
+    enum NotificationRoles {
+        ReportRole = ExtraRole,
+        RelationshipSeveranceEventRole,
+        ModerationWarningRole,
+        AnnualReportEventRole,
+    };
 
     explicit NotificationModel(QObject *parent = nullptr);
 
@@ -79,6 +84,11 @@ public Q_SLOTS:
      */
     void actionBookmark(const QModelIndex &index);
 
+    /**
+     * @brief Mute the notification at @p index.
+     */
+    void actionMute(const QModelIndex &index);
+
 Q_SIGNALS:
     /**
      * @brief Emitted when the list of excluded notification types change
