@@ -11,6 +11,8 @@
 #include "utils/texthandler.h"
 
 #include <KLocalizedString>
+#include <QJsonDocument>
+#include <QNetworkReply>
 
 using namespace Qt::Literals::StringLiterals;
 
@@ -32,7 +34,6 @@ static const QMap<QString, Post::Visibility> p_stringToVisibility = {
 Post::Post(AbstractAccount *account, QObject *parent)
     : QObject(parent)
     , m_parent(account)
-    , m_attachmentList(this, &m_attachments)
 {
     Q_ASSERT(account);
     QString visibilityString = account->identity()->visibility();
@@ -42,7 +43,6 @@ Post::Post(AbstractAccount *account, QObject *parent)
 Post::Post(AbstractAccount *account, QJsonObject obj, QObject *parent)
     : QObject(parent)
     , m_parent(account)
-    , m_attachmentList(this, &m_attachments)
     , m_visibility(Post::Visibility::Public)
 {
     Q_ASSERT(account);
@@ -428,11 +428,6 @@ Identity *Post::getAuthorIdentity() const
     return authorIdentity().get();
 }
 
-QQmlListProperty<Attachment> Post::attachmentList() const
-{
-    return m_attachmentList;
-}
-
 Card *Post::getCard() const
 {
     if (m_card.has_value()) {
@@ -513,6 +508,11 @@ void Post::processContent(const QJsonObject &obj)
     m_content = standaloneContent;
 }
 
+bool Post::hasPoll() const
+{
+    return m_poll.operator bool();
+}
+
 Card::Card(AbstractAccount *account, QJsonObject card)
     : m_card(card)
     , m_account(account)
