@@ -15,6 +15,7 @@ class TagsTimelineModel : public TimelineModel
     QML_ELEMENT
 
     Q_PROPERTY(QString hashtag READ hashtag WRITE setHashtag NOTIFY hashtagChanged)
+    Q_PROPERTY(bool following READ following NOTIFY followedChanged)
 
 public:
     explicit TagsTimelineModel(QObject *parent = nullptr);
@@ -22,6 +23,7 @@ public:
 
     void fillTimeline(const QString &fromId, bool backwards = false) override;
     [[nodiscard]] QString displayName() const override;
+    bool canFetchMore(const QModelIndex &parent) const override;
 
     /**
      * @brief The hashtag the timeline is searching for.
@@ -37,6 +39,24 @@ public:
 
     void reset() override;
 
+    /**
+     * @return If the current account is following this hashtag.
+     */
+    bool following() const;
+
+    bool atEnd() const override;
+
+public Q_SLOTS:
+    /**
+     * @brief Follow this hashtag.
+     */
+    void follow();
+
+    /**
+     * @brief Unfollow this hashtag.
+     */
+    void unfollow();
+
 Q_SIGNALS:
     /**
      * @brief Emitted if the hashtag is changed
@@ -44,6 +64,14 @@ Q_SIGNALS:
      */
     void hashtagChanged();
 
+    /**
+     * @brief Emitted if the hashtag was followed or unfollowed.
+     * @see follow() unfollow()
+     */
+    void followedChanged();
+
 private:
     QString m_hashtag;
+    bool m_following = false;
+    std::optional<QUrl> m_next;
 };
