@@ -4,6 +4,9 @@
 
 #include "timeline/timelinemodel.h"
 
+#include <QJsonDocument>
+#include <QNetworkReply>
+
 using namespace Qt::Literals::StringLiterals;
 
 TimelineModel::TimelineModel(QObject *parent)
@@ -30,7 +33,7 @@ void TimelineModel::init()
         fillTimeline();
     });
 
-    connect(m_manager, &AccountManager::accountSelected, this, [=](AbstractAccount *account) {
+    connect(m_manager, &AccountManager::accountSelected, this, [this](AbstractAccount *account) {
         if (m_account == account || account == nullptr) {
             return;
         }
@@ -70,7 +73,7 @@ int TimelineModel::fetchedTimeline(const QByteArray &data, bool alwaysAppendToEn
         return 0;
     }
 
-    std::transform(array.cbegin(), array.cend(), std::back_inserter(posts), [this](const QJsonValue &value) -> Post * {
+    std::ranges::transform(std::as_const(array), std::back_inserter(posts), [this](const QJsonValue &value) -> Post * {
         auto post = new Post(m_account, value.toObject(), this);
         if (!post->hidden()) {
             return post;
@@ -79,19 +82,34 @@ int TimelineModel::fetchedTimeline(const QByteArray &data, bool alwaysAppendToEn
         }
     });
 
-    posts.erase(std::remove_if(posts.begin(),
-                               posts.end(),
-                               [this](Post *post) {
-                                   if (!m_showBoosts && post->boostIdentity()) {
-                                       return true;
-                                   }
-                                   if (!m_showReplies && !post->inReplyTo().isEmpty()) {
-                                       return true;
-                                   }
-                                   return post == nullptr;
-                               }),
+    posts.erase(std::ranges::remove_if(posts,
+                                       [this](Post *post) {
+                                           // Don't show boosts if requested
+                                           if (!m_showBoosts && post->boostIdentity()) {
+                                               return true;
+                                           }
+                                           // Don't show replies if requested
+                                           if (!m_showReplies && !post->inReplyTo().isEmpty()) {
+                                               return true;
+                                           }
+                                           // Make sure we aren't adding the same post we already have
+                                           const auto it = std::ranges::find_if(std::as_const(m_timeline), [post](const auto &timelinePost) {
+                                               return post->postId() == timelinePost->postId();
+                                           });
+                                           if (it != std::end(m_timeline)) {
+                                               return true;
+                                           }
+
+                                           return post == nullptr;
+                                       })
+                    .begin(),
                 posts.end());
 
+    // If we ended up removing all of the posts we were going to add, quit
+    if (posts.empty()) {
+        return 0;
+    }
+
     for (auto &post : posts) {
         // If we are still waiting on the reply identity, make sure to update it's row
         if (!post->inReplyTo().isEmpty() && post->replyIdentity() == nullptr) {
@@ -214,11 +232,9 @@ void TimelineModel::actionVote(const QModelIndex &index, const QList<int> &choic
 
     QJsonObject obj;
     QJsonArray array;
-    std::transform(
-        choices.cbegin(),
-        choices.cend(),
-        std::back_inserter(array),
-        [](int choice) -> auto{ return choice; });
+    std::ranges::transform(std::as_const(choices), std::back_inserter(array), [](int choice) -> auto {
+        return choice;
+    });
     obj["choices"_L1] = array;
     QJsonDocument doc(obj);
     const auto id = poll->id();
@@ -273,6 +289,14 @@ void TimelineModel::actionDelete(const QModelIndex &index)
     endRemoveRows();
 }
 
+void TimelineModel::actionMute(const QModelIndex &index)
+{
+    int row = index.row();
+    auto p = m_timeline[row];
+
+    AbstractTimelineModel::actionMute(index, p);
+}
+
 void TimelineModel::handleEvent(AbstractAccount::StreamingEventType eventType, const QByteArray &payload)
 {
     if (eventType == AbstractAccount::StreamingEventType::DeleteEvent) {
