@@ -5,8 +5,6 @@
 
 #include <AbstractKirigamiApplication>
 #include <QObject>
-#include <QQmlEngine>
-#include <QSortFilterProxyModel>
 
 #include "account/accountmanager.h"
 
@@ -18,7 +16,7 @@ class TokodonApplication : public AbstractKirigamiApplication
     Q_PROPERTY(AccountManager *accountManager READ accountManager WRITE setAccountManager NOTIFY accountManagerChanged)
 
 public:
-    TokodonApplication(QObject *parent = nullptr);
+    explicit TokodonApplication(QObject *parent = nullptr);
     ~TokodonApplication() override = default;
 
     [[nodiscard]] AccountManager *accountManager() const;
@@ -42,4 +40,4 @@ private:
     KirigamiActionCollection *m_accountCollection = nullptr;
     QHash<AbstractAccount *, QAction *> m_switchUserActions;
     QHash<AbstractAccount *, QAction *> m_configureUserActions;
-};
\ No newline at end of file
+};
